@@ -74,7 +74,7 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
   public $_activityProfileFields;
 
   /**
-   * The id of the survey (petition) we are proceessing
+   * The id of the survey (petition) we are processing
    *
    * @var int
    */
@@ -116,6 +116,13 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
 
   protected $_image_URL;
 
+  /**
+   * Prevent double clicks from creating duplicate or blank records.
+   *
+   * @var bool
+   */
+  public $submitOnce = TRUE;
+
   /**
    */
   public function __construct() {
@@ -152,6 +159,27 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
     return $session->get('userID');
   }
 
+  /**
+   * Get the active UFGroups (profiles) on this form
+   * Many forms load one or more UFGroups (profiles).
+   * This provides a standard function to retrieve the IDs of those profiles from the form
+   * so that you can implement things such as "is is_captcha field set on any of the active profiles on this form?"
+   *
+   * NOT SUPPORTED FOR USE OUTSIDE CORE EXTENSIONS - Added for reCAPTCHA core extension.
+   *
+   * @return array
+   */
+  public function getUFGroupIDs() {
+    $ufGroupIDs = [];
+    if (!empty($this->_contactProfileId)) {
+      $ufGroupIDs[] = $this->_contactProfileId;
+    }
+    if (!empty($this->_activityProfileId)) {
+      $ufGroupIDs[] = $this->_activityProfileId;
+    }
+    return $ufGroupIDs;
+  }
+
   public function preProcess() {
     $this->bao = new CRM_Campaign_BAO_Petition();
     $this->_mode = self::MODE_CREATE;
@@ -161,7 +189,7 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
 
     //some sanity checks
     if (!$this->_surveyId) {
-      CRM_Core_Error::statusBounce('Petition id is not valid. (it needs a "sid" in the url).');
+      CRM_Core_Error::statusBounce(ts('Petition id is not valid. (it needs a "sid" in the url).'));
       return;
     }
     //check petition is valid and active
@@ -169,10 +197,13 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
     $this->petition = [];
     CRM_Campaign_BAO_Survey::retrieve($params, $this->petition);
     if (empty($this->petition)) {
-      CRM_Core_Error::statusBounce('Petition doesn\'t exist.');
+      CRM_Core_Error::statusBounce(ts('Petition doesn\'t exist.'));
     }
     if ($this->petition['is_active'] == 0) {
-      CRM_Core_Error::statusBounce('Petition is no longer active.');
+      $this->assign('isActive', FALSE);
+    }
+    else {
+      $this->assign('isActive', TRUE);
     }
 
     //get userID from session
@@ -198,7 +229,7 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
       $this->_contactProfileFields = CRM_Core_BAO_UFGroup::getFields($this->_contactProfileId, FALSE, CRM_Core_Action::ADD);
     }
     if (!isset($this->_contactProfileFields['email-Primary'])) {
-      CRM_Core_Error::statusBounce('The contact profile needs to contain the primary email address field');
+      CRM_Core_Error::statusBounce(ts('The contact profile needs to contain the primary email address field'));
     }
 
     $ufJoinParams['weight'] = 1;
@@ -209,7 +240,7 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
     }
 
     $this->setDefaultValues();
-    CRM_Utils_System::setTitle($this->petition['title']);
+    $this->setTitle($this->petition['title']);
   }
 
   /**
@@ -314,13 +345,15 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
     $tag_name = Civi::settings()->get('tag_unconfirmed');
 
     if ($tag_name) {
-      // Check if contact 'email confirmed' tag exists, else create one
+      // Check if contact 'Unconfirmed' tag exists, else create one
       // This should be in the petition module initialise code to create a default tag for this
       $tag_params['name'] = $tag_name;
       $tag_params['version'] = 3;
       $tag = civicrm_api('tag', 'get', $tag_params);
       if ($tag['count'] == 0) {
         //create tag
+        $tag_params['label'] = ts('Unconfirmed');
+        $tag_params['color'] = '#ffdd00';
         $tag_params['description'] = $tag_name;
         $tag_params['is_reserved'] = 1;
         $tag_params['used_for'] = 'civicrm_contact';
@@ -471,14 +504,6 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
     // get additional custom activity profile field data
     // to save with new signature activity record
     $surveyInfo = $this->bao->getSurveyInfo($this->_surveyId);
-    $customActivityFields = CRM_Core_BAO_CustomField::getFields('Activity', FALSE, FALSE,
-      $surveyInfo['activity_type_id']
-    );
-    $customActivityFields = CRM_Utils_Array::crmArrayMerge($customActivityFields,
-      CRM_Core_BAO_CustomField::getFields('Activity', FALSE, FALSE,
-        NULL, NULL, TRUE
-      )
-    );
 
     $params['custom'] = CRM_Core_BAO_CustomField::postProcess($params,
       NULL,
@@ -544,9 +569,8 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
    *
    * @param int $id
    * @param string $name
-   * @param bool $viewOnly
    */
-  public function buildCustom($id, $name, $viewOnly = FALSE) {
+  public function buildCustom($id, $name) {
     if ($id) {
       $session = CRM_Core_Session::singleton();
       $this->assign("petition", $this->petition);
@@ -568,29 +592,12 @@ class CRM_Campaign_Form_Petition_Signature extends CRM_Core_Form {
       if ($fields) {
         $this->assign($name, $fields);
 
-        $addCaptcha = FALSE;
         foreach ($fields as $key => $field) {
-          if ($viewOnly &&
-            isset($field['data_type']) &&
-            $field['data_type'] == 'File' || ($viewOnly && $field['name'] == 'image_URL')
-          ) {
-            // ignore file upload fields
-            continue;
-          }
-
           // if state or country in the profile, create map
           list($prefixName, $index) = CRM_Utils_System::explode('-', $key, 2);
 
           CRM_Core_BAO_UFGroup::buildProfile($this, $field, CRM_Profile_Form::MODE_CREATE, $contactID, TRUE);
           $this->_fields[$key] = $field;
-          // CRM-11316 Is ReCAPTCHA enabled for this profile AND is this an anonymous visitor
-          if ($field['add_captcha'] && !$this->_contactId) {
-            $addCaptcha = TRUE;
-          }
-        }
-
-        if ($addCaptcha && !$viewOnly) {
-          CRM_Utils_ReCAPTCHA::enableCaptchaOnForm($this);
         }
       }
     }
