@@ -40,7 +40,7 @@ class CRM_Utils_Check_Component_Case extends CRM_Utils_Check_Component {
    * @inheritDoc
    */
   public function isEnabled() {
-    return CRM_Case_BAO_Case::enabled();
+    return CRM_Case_BAO_Case::isComponentEnabled();
   }
 
   /**
@@ -361,17 +361,15 @@ class CRM_Utils_Check_Component_Case extends CRM_Utils_Check_Component {
       }
       $messages[] = new CRM_Utils_Check_Message(
         __FUNCTION__ . "missingroles",
-        ts("<p>The following roles listed in your case type definitions do not match any relationship type defined in the system: <em>%1</em>.</p>"
-          . "<p>This might be because of a mismatch if you are using external xml files to manage case types. If using xml files, then use either the name_a_b or name_b_a value from the following table. (Out of the box you would use name_b_a, which lists them on the case from the client perspective.) If you are not using xml files, you can edit your case types at Administer - CiviCase - Case Types.</p>"
-          . "<table>
-            <tr><th>ID</th><th>name_a_b</th><th>name_b_a</th><th>label_a_b</th><th>label_b_a</th></tr>"
+        '<p>' . ts("The following roles listed in your case type definitions do not match any relationship type defined in the system: <em>%1</em>.", [1 => htmlspecialchars(implode(', ', $missing))]) . '</p>'
+          . "<p>" . ts("This might be because of a mismatch if you are using external xml files to manage case types. If using xml files, then use either the name_a_b or name_b_a value from the following table. (Out of the box you would use name_b_a, which lists them on the case from the client perspective.) If you are not using xml files, you can edit your case types at Administer - CiviCase - Case Types.") . '</p>'
+          . '<table>'
+          . '<tr><th>ID</th><th>name_a_b</th><th>name_b_a</th><th>label_a_b</th><th>label_b_a</th></tr>'
           . implode("\n", $tableRows)
-          . "</table>", [
-            1 => htmlspecialchars(implode(', ', $missing)),
-          ]) .
-          '<br /><a href="' . CRM_Utils_System::docURL2('user/case-management/what-you-need-to-know#missing-roles', TRUE) . '">' .
-          ts('Read more about this warning') .
-          '</a>',
+          . '</table>'
+          . '<br /><a href="' . CRM_Utils_System::docURL2('user/case-management/what-you-need-to-know#missing-roles', TRUE) . '">'
+          . ts('Read more about this warning')
+          . '</a>',
         ts('Missing Roles'),
         \Psr\Log\LogLevel::ERROR,
         'fa-exclamation'
@@ -491,4 +489,32 @@ class CRM_Utils_Check_Component_Case extends CRM_Utils_Check_Component {
     return $messages;
   }
 
+  /**
+   * At some point the valid names changed so that you can't have e.g. spaces.
+   * For systems upgraded that use external xml files it's then not clear why
+   * the other messages about outdated filenames are coming up because when
+   * you then fix it as suggested it then gives a red error just saying it
+   * can't find it.
+   */
+  public function checkCaseTypeNameValidity() {
+    $messages = [];
+    $dao = CRM_Core_DAO::executeQuery("SELECT id, name, title FROM civicrm_case_type");
+    while ($dao->fetch()) {
+      if (!CRM_Case_BAO_CaseType::isValidName($dao->name)) {
+        $messages[] = new CRM_Utils_Check_Message(
+          __FUNCTION__ . "invalidcasetypename",
+          '<p>' . ts('Case Type "<em>%1</em>" has invalid characters in the internal machine name (<em>%2</em>). Only letters, numbers, and underscore are allowed.',
+          [
+            1 => htmlspecialchars(empty($dao->title) ? $dao->id : $dao->title),
+            2 => htmlspecialchars($dao->name),
+          ]) . '</p>',
+          ts('Invalid Case Type Name'),
+          \Psr\Log\LogLevel::ERROR,
+          'fa-exclamation'
+        );
+      }
+    }
+    return $messages;
+  }
+
 }
